==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZlecenieWydanieWyrob.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ZlecenieWydanieWyrob extends GenericDPSObject {
    /**
     * ZLECENIE_WYDANIE_WYROB.ZLECENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zlecenieId;

    /**
     * ZLECENIE_WYDANIE_WYROB.DANE_WM
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String daneWm;

    /**
     * ZLECENIE_WYDANIE_WYROB.DATA_ODBIORU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOdbioru;

    /**
     * ZLECENIE_WYDANIE_WYROB.KWOTA_NFZ
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaNfz;

    /**
     * ZLECENIE_WYDANIE_WYROB.KWOTA_SWIADCZENIOBIORCA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaSwiadczeniobiorca;

    /**
     * ZLECENIE_WYDANIE_WYROB.NR_UMOWY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nrUmowy;

    /**
     * ZLECENIE_WYDANIE_WYROB.LICZBA_SZTUK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer liczbaSztuk;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_WYDANIE_WYROB.ZLECENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZlecenieId() {
        return zlecenieId;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.ZLECENIE_ID
     *
     * @param zlecenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZlecenieId(Long zlecenieId) {
        this.zlecenieId = zlecenieId;
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.DANE_WM
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getDaneWm() {
        return daneWm;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.DANE_WM
     *
     * @param daneWm
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDaneWm(String daneWm) {
        this.daneWm = daneWm == null ? null : daneWm.trim();
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.DATA_ODBIORU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOdbioru() {
        return dataOdbioru;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.DATA_ODBIORU
     *
     * @param dataOdbioru
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOdbioru(Date dataOdbioru) {
        this.dataOdbioru = dataOdbioru;
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.KWOTA_NFZ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaNfz() {
        return kwotaNfz;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.KWOTA_NFZ
     *
     * @param kwotaNfz
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaNfz(BigDecimal kwotaNfz) {
        this.kwotaNfz = kwotaNfz;
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.KWOTA_SWIADCZENIOBIORCA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaSwiadczeniobiorca() {
        return kwotaSwiadczeniobiorca;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.KWOTA_SWIADCZENIOBIORCA
     *
     * @param kwotaSwiadczeniobiorca
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaSwiadczeniobiorca(BigDecimal kwotaSwiadczeniobiorca) {
        this.kwotaSwiadczeniobiorca = kwotaSwiadczeniobiorca;
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.NR_UMOWY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNrUmowy() {
        return nrUmowy;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.NR_UMOWY
     *
     * @param nrUmowy
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNrUmowy(String nrUmowy) {
        this.nrUmowy = nrUmowy == null ? null : nrUmowy.trim();
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.LICZBA_SZTUK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getLiczbaSztuk() {
        return liczbaSztuk;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.LICZBA_SZTUK
     *
     * @param liczbaSztuk
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLiczbaSztuk(Integer liczbaSztuk) {
        this.liczbaSztuk = liczbaSztuk;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZlecenieWydanieWyrob other = (ZlecenieWydanieWyrob) that;
        return (this.getZlecenieId() == null ? other.getZlecenieId() == null : this.getZlecenieId().equals(other.getZlecenieId()))
            && (this.getDaneWm() == null ? other.getDaneWm() == null : this.getDaneWm().equals(other.getDaneWm()))
            && (this.getDataOdbioru() == null ? other.getDataOdbioru() == null : this.getDataOdbioru().equals(other.getDataOdbioru()))
            && (this.getKwotaNfz() == null ? other.getKwotaNfz() == null : this.getKwotaNfz().equals(other.getKwotaNfz()))
            && (this.getKwotaSwiadczeniobiorca() == null ? other.getKwotaSwiadczeniobiorca() == null : this.getKwotaSwiadczeniobiorca().equals(other.getKwotaSwiadczeniobiorca()))
            && (this.getNrUmowy() == null ? other.getNrUmowy() == null : this.getNrUmowy().equals(other.getNrUmowy()))
            && (this.getLiczbaSztuk() == null ? other.getLiczbaSztuk() == null : this.getLiczbaSztuk().equals(other.getLiczbaSztuk()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getZlecenieId() == null) ? 0 : getZlecenieId().hashCode());
        result = prime * result + ((getDaneWm() == null) ? 0 : getDaneWm().hashCode());
        result = prime * result + ((getDataOdbioru() == null) ? 0 : getDataOdbioru().hashCode());
        result = prime * result + ((getKwotaNfz() == null) ? 0 : getKwotaNfz().hashCode());
        result = prime * result + ((getKwotaSwiadczeniobiorca() == null) ? 0 : getKwotaSwiadczeniobiorca().hashCode());
        result = prime * result + ((getNrUmowy() == null) ? 0 : getNrUmowy().hashCode());
        result = prime * result + ((getLiczbaSztuk() == null) ? 0 : getLiczbaSztuk().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", zlecenieId=").append(zlecenieId);
        sb.append(", daneWm=").append(daneWm);
        sb.append(", dataOdbioru=").append(dataOdbioru);
        sb.append(", kwotaNfz=").append(kwotaNfz);
        sb.append(", kwotaSwiadczeniobiorca=").append(kwotaSwiadczeniobiorca);
        sb.append(", nrUmowy=").append(nrUmowy);
        sb.append(", liczbaSztuk=").append(liczbaSztuk);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZlecenieWydanieWyrob.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ZlecenieWydanieWyrob extends GenericDPSObject {
    /**
     * ZLECENIE_WYDANIE_WYROB.ZLECENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zlecenieId;

    /**
     * ZLECENIE_WYDANIE_WYROB.DANE_WM
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String daneWm;

    /**
     * ZLECENIE_WYDANIE_WYROB.DATA_ODBIORU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOdbioru;

    /**
     * ZLECENIE_WYDANIE_WYROB.KWOTA_NFZ
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaNfz;

    /**
     * ZLECENIE_WYDANIE_WYROB.KWOTA_SWIADCZENIOBIORCA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaSwiadczeniobiorca;

    /**
     * ZLECENIE_WYDANIE_WYROB.NR_UMOWY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nrUmowy;

    /**
     * ZLECENIE_WYDANIE_WYROB.LICZBA_SZTUK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer liczbaSztuk;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_WYDANIE_WYROB.ZLECENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZlecenieId() {
        return zlecenieId;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.ZLECENIE_ID
     *
     * @param zlecenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZlecenieId(Long zlecenieId) {
        this.zlecenieId = zlecenieId;
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.DANE_WM
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getDaneWm() {
        return daneWm;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.DANE_WM
     *
     * @param daneWm
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDaneWm(String daneWm) {
        this.daneWm = daneWm == null ? null : daneWm.trim();
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.DATA_ODBIORU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOdbioru() {
        return dataOdbioru;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.DATA_ODBIORU
     *
     * @param dataOdbioru
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOdbioru(Date dataOdbioru) {
        this.dataOdbioru = dataOdbioru;
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.KWOTA_NFZ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaNfz() {
        return kwotaNfz;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.KWOTA_NFZ
     *
     * @param kwotaNfz
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaNfz(BigDecimal kwotaNfz) {
        this.kwotaNfz = kwotaNfz;
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.KWOTA_SWIADCZENIOBIORCA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaSwiadczeniobiorca() {
        return kwotaSwiadczeniobiorca;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.KWOTA_SWIADCZENIOBIORCA
     *
     * @param kwotaSwiadczeniobiorca
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaSwiadczeniobiorca(BigDecimal kwotaSwiadczeniobiorca) {
        this.kwotaSwiadczeniobiorca = kwotaSwiadczeniobiorca;
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.NR_UMOWY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNrUmowy() {
        return nrUmowy;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.NR_UMOWY
     *
     * @param nrUmowy
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNrUmowy(String nrUmowy) {
        this.nrUmowy = nrUmowy == null ? null : nrUmowy.trim();
    }

    /**
     * @return ZLECENIE_WYDANIE_WYROB.LICZBA_SZTUK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getLiczbaSztuk() {
        return liczbaSztuk;
    }

    /**
     * ZLECENIE_WYDANIE_WYROB.LICZBA_SZTUK
     *
     * @param liczbaSztuk
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLiczbaSztuk(Integer liczbaSztuk) {
        this.liczbaSztuk = liczbaSztuk;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZlecenieWydanieWyrob other = (ZlecenieWydanieWyrob) that;
        return (this.getZlecenieId() == null ? other.getZlecenieId() == null : this.getZlecenieId().equals(other.getZlecenieId()))
            && (this.getDaneWm() == null ? other.getDaneWm() == null : this.getDaneWm().equals(other.getDaneWm()))
            && (this.getDataOdbioru() == null ? other.getDataOdbioru() == null : this.getDataOdbioru().equals(other.getDataOdbioru()))
            && (this.getKwotaNfz() == null ? other.getKwotaNfz() == null : this.getKwotaNfz().equals(other.getKwotaNfz()))
            && (this.getKwotaSwiadczeniobiorca() == null ? other.getKwotaSwiadczeniobiorca() == null : this.getKwotaSwiadczeniobiorca().equals(other.getKwotaSwiadczeniobiorca()))
            && (this.getNrUmowy() == null ? other.getNrUmowy() == null : this.getNrUmowy().equals(other.getNrUmowy()))
            && (this.getLiczbaSztuk() == null ? other.getLiczbaSztuk() == null : this.getLiczbaSztuk().equals(other.getLiczbaSztuk()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getZlecenieId() == null) ? 0 : getZlecenieId().hashCode());
        result = prime * result + ((getDaneWm() == null) ? 0 : getDaneWm().hashCode());
        result = prime * result + ((getDataOdbioru() == null) ? 0 : getDataOdbioru().hashCode());
        result = prime * result + ((getKwotaNfz() == null) ? 0 : getKwotaNfz().hashCode());
        result = prime * result + ((getKwotaSwiadczeniobiorca() == null) ? 0 : getKwotaSwiadczeniobiorca().hashCode());
        result = prime * result + ((getNrUmowy() == null) ? 0 : getNrUmowy().hashCode());
        result = prime * result + ((getLiczbaSztuk() == null) ? 0 : getLiczbaSztuk().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", zlecenieId=").append(zlecenieId);
        sb.append(", daneWm=").append(daneWm);
        sb.append(", dataOdbioru=").append(dataOdbioru);
        sb.append(", kwotaNfz=").append(kwotaNfz);
        sb.append(", kwotaSwiadczeniobiorca=").append(kwotaSwiadczeniobiorca);
        sb.append(", nrUmowy=").append(nrUmowy);
        sb.append(", liczbaSztuk=").append(liczbaSztuk);
        sb.append("]");
        return sb.toString();
    }
}
